pyxmpp2.mainloop.events

Package pyxmpp2 :: Package mainloop :: Module events |
[hide private]

# Module events

PyXMPP events.

Classes | [hide private]
| EventDispatcher Dispatches events from an event queue to event handlers.

Functions | [hide private]
_event_queue_factory(settings) Create the default event queue object. |

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.mainloop.events")`

Function Details | [hide private]

### _event_queue_factory(settings) |
Create the default event queue object. Use the `event_queue_max_size setting` for the maximum queue size.